@@ -23,7 +23,17 @@ from djview.qsutil import *
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.core.urlresolvers import reverse
-from django.http import Http404, HttpResponse, HttpResponseRedirect
+from django.http import (Http404,
+                         HttpResponse, 
+                         HttpResponseBadRequest,
+                         HttpResponseForbidden,
+                         HttpResponseGone,
+                         HttpResponseNotAllowed,
+                         HttpResponseNotFound,
+                         HttpResponseNotModified,
+                         HttpResponsePermanentRedirect,
+                         HttpResponseRedirect,
+                         HttpResponseServerError)
 from django.shortcuts import get_object_or_404, render_to_response
 from django.template.loader import render_to_string
 from django.views.decorators.cache import cache_page
@@ -89,3 +99,18 @@ def json(func):
             data=_jsonutil.dumps(res)
             return HttpResponse(data, mimetype='application/json')
     return wrapper
+
+def jsonp(func):
+    def wrapper(request, *args, **kwargs):
+        res=func(request, *args, **kwargs)
+        if isinstance(res, HttpResponse):
+            return res
+        elif request.method=='GET' and 'callback' in request.GET:
+            body=u'%s(%s)' % (request.GET['callback'],
+                              _jsonutil.dumps(res))
+            return HttpResponse(body, mimetype='text/javascript')
+        else:
+            data=_jsonutil.dumps(res)
+            return HttpResponse(data, mimetype='application/json')
+    return wrapper
+    
